import { render } from '../';
import '../extend-expect';

import { Empty, GetByAltText, LabelText, LabelWithNoFormControl, Placeholder, TotallyEmptyLabel, AltText, JestHelpers } from './components/queries';

test('query can return null', function () {
  var _render = render(Empty),
      queryByLabelText = _render.queryByLabelText,
      queryByPlaceholderText = _render.queryByPlaceholderText,
      queryByText = _render.queryByText,
      queryByTestId = _render.queryByTestId,
      queryByAltText = _render.queryByAltText;

  expect(queryByTestId('LucyRicardo')).toBeNull();
  expect(queryByLabelText('LucyRicardo')).toBeNull();
  expect(queryByPlaceholderText('LucyRicardo')).toBeNull();
  expect(queryByText('LucyRicardo')).toBeNull();
  expect(queryByAltText('LucyRicardo')).toBeNull();
});

test('get throws a useful error message', function () {
  var _render2 = render(Empty),
      getByLabelText = _render2.getByLabelText,
      getByPlaceholderText = _render2.getByPlaceholderText,
      getByText = _render2.getByText,
      getByTestId = _render2.getByTestId,
      getByAltText = _render2.getByAltText;

  expect(function () {
    return getByLabelText('LucyRicardo');
  }).toThrowErrorMatchingSnapshot();
  expect(function () {
    return getByPlaceholderText('LucyRicardo');
  }).toThrowErrorMatchingSnapshot();
  expect(function () {
    return getByText('LucyRicardo');
  }).toThrowErrorMatchingSnapshot();
  expect(function () {
    return getByTestId('LucyRicardo');
  }).toThrowErrorMatchingSnapshot();
  expect(function () {
    return getByAltText('LucyRicardo');
  }).toThrowErrorMatchingSnapshot();
});

test('get can get form controls by label text', function () {
  var _render3 = render(LabelText),
      getByLabelText = _render3.getByLabelText;

  expect(getByLabelText('1st').id).toBe('first-id');
  expect(getByLabelText('2nd').id).toBe('second-id');
  expect(getByLabelText('3rd').id).toBe('third-id');
});

test('get can get form controls by placeholder', function () {
  var _render4 = render(Placeholder),
      getByPlaceholderText = _render4.getByPlaceholderText;

  expect(getByPlaceholderText('username').id).toBe('username-id');
});

test('label with no form control', function () {
  var _render5 = render(LabelWithNoFormControl),
      getByLabelText = _render5.getByLabelText,
      queryByLabelText = _render5.queryByLabelText;

  expect(queryByLabelText('alone')).toBeNull();
  expect(function () {
    return getByLabelText('alone');
  }).toThrowErrorMatchingSnapshot();
});

test('totally empty label', function () {
  var _render6 = render(TotallyEmptyLabel),
      getByLabelText = _render6.getByLabelText,
      queryByLabelText = _render6.queryByLabelText;

  expect(queryByLabelText('')).toBeNull();
  expect(function () {
    return getByLabelText('');
  }).toThrowErrorMatchingSnapshot();
});

test('get element by its alt text', function () {
  var _render7 = render(GetByAltText),
      getByAltText = _render7.getByAltText;

  expect(getByAltText(/fin.*nem.*poster$/i).src).toBe('/finding-nemo.png');
});

test('using jest helpers to assert element states', function () {
  var _render8 = render(JestHelpers),
      queryByTestId = _render8.queryByTestId;

  // other ways to assert your test cases, but you don't need all of them.


  expect(queryByTestId('count-value')).toBeInTheDOM();
  expect(queryByTestId('count-value1')).not.toBeInTheDOM();
  expect(queryByTestId('count-value')).toHaveTextContent('2');
  expect(queryByTestId('count-value')).not.toHaveTextContent('21');
  expect(function () {
    return expect(queryByTestId('count-value2')).toHaveTextContent('2');
  }).toThrowError();

  // negative test cases wrapped in throwError assertions for coverage.
  expect(function () {
    return expect(queryByTestId('count-value')).not.toBeInTheDOM();
  }).toThrowError();
  expect(function () {
    return expect(queryByTestId('count-value1')).toBeInTheDOM();
  }).toThrowError();
  expect(function () {
    return expect(queryByTestId('count-value')).toHaveTextContent('3');
  }).toThrowError();
  expect(function () {
    return expect(queryByTestId('count-value')).not.toHaveTextContent('2');
  }).toThrowError();
});

/* eslint jsx-a11y/label-has-for:0 */