import Vue from 'vue';
import { render, Simulate } from '../';
import Login from './components/Login';

test('login form submits', function () {
  var fakeUser = { username: 'jackiechan', password: 'hiya! 🥋' };
  var handleSubmit = jest.fn();

  var _render = render(Login, { props: { onSubmit: handleSubmit } }),
      wrapper = _render.wrapper,
      getByLabelText = _render.getByLabelText,
      getByText = _render.getByText;

  var usernameNode = getByLabelText('username');
  var passwordNode = getByLabelText('password');
  var formNode = wrapper.find('form');
  var submitButtonNode = getByText('submit');

  // Act - this is waiting on an issue in @vue/test-utils to allow v-model to be updated by
  // changes to DOM elements

  // Simulate.change(usernameNode, fakeUser.username)
  // Simulate.change(passwordNode, fakeUser.password)
  wrapper.setData(fakeUser);

  // NOTE: in jsdom, it's not possible to trigger a form submission
  // by clicking on the submit button. This is really unfortunate.
  // So the next best thing is to simulate a submit on the form itself
  // then ensure that there's a submit button.
  Simulate.submit(formNode);

  // Assert
  expect(handleSubmit).toHaveBeenCalledTimes(1);
  expect(handleSubmit).toHaveBeenCalledWith(fakeUser);
  // make sure the form is submittable
  expect(submitButtonNode.type).toBe('submit');
});