import VuexTest from './components/VuexTest';
import { render, Simulate } from '../';
import Vuex from 'vuex';

var store = {
  state: {
    count: 0
  },
  actions: {
    increment: function increment(_ref) {
      var commit = _ref.commit,
          state = _ref.state;
      return commit('SET_COUNT', state.count + 1);
    },
    decrement: function decrement(_ref2) {
      var commit = _ref2.commit,
          state = _ref2.state;
      return commit('SET_COUNT', state.count - 1);
    }
  },
  mutations: {
    SET_COUNT: function SET_COUNT(state, count) {
      return state.count = count;
    }
  }
};

test('can render with vuex with defaults', function () {
  var _render = render(VuexTest, { store: store }),
      getByTestId = _render.getByTestId,
      getByText = _render.getByText;

  Simulate.click(getByText('+'));
  expect(getByTestId('count-value').textContent).toBe('1');
});

test('can render with vuex with custom initial state', function () {
  store.state.count = 3;

  var _render2 = render(VuexTest, { store: store }),
      getByTestId = _render2.getByTestId,
      getByText = _render2.getByText;

  Simulate.click(getByText('-'));
  expect(getByTestId('count-value').textContent).toBe('2');
});

test('can render with vuex with custom store', function () {
  // this is a silly store that can never be changed
  var store = { state: { count: 1000 } };

  var _render3 = render(VuexTest, { store: store }),
      getByTestId = _render3.getByTestId,
      getByText = _render3.getByText;

  Simulate.click(getByText('+'));
  expect(getByTestId('count-value').textContent).toBe('1000');
  Simulate.click(getByText('-'));
  expect(getByTestId('count-value').textContent).toBe('1000');
});