import _slicedToArray from 'babel-runtime/helpers/slicedToArray';
import _Object$entries from 'babel-runtime/core-js/object/entries';
import _extends from 'babel-runtime/helpers/extends';
import { createLocalVue, mount, Wrapper } from '@vue/test-utils';
import Vuex from 'vuex';
import VueRouter from 'vue-router';
import waitForExpect from 'wait-for-expect';
import Simulate from './Simulate';
import * as queries from './queries';

function render(TestComponent) {
  var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      _ref$props = _ref.props,
      props = _ref$props === undefined ? null : _ref$props,
      _ref$store = _ref.store,
      store = _ref$store === undefined ? null : _ref$store,
      _ref$routes = _ref.routes,
      routes = _ref$routes === undefined ? null : _ref$routes;

  var localVue = createLocalVue();
  var vuexStore = null;
  var router = null;

  if (store) {
    localVue.use(Vuex);
    vuexStore = new Vuex.Store(store);
  }

  if (routes) {
    localVue.use(VueRouter);
    router = new VueRouter(routes);
  }

  var wrapper = mount(TestComponent, {
    localVue: localVue,
    router: router,
    store: vuexStore,
    propsData: _extends({}, props),
    attachToDocument: true
  });

  var wrapperHelpers = _Object$entries(queries).reduce(function (helpers, _ref2) {
    var _ref3 = _slicedToArray(_ref2, 2),
        key = _ref3[0],
        fn = _ref3[1];

    helpers[key] = fn.bind(null, wrapper);
    return helpers;
  }, {});

  return _extends({
    wrapper: wrapper,
    unmount: function unmount() {
      return wrapper.destroy(true);
    }
  }, wrapperHelpers);
}

function wait() {
  var callback = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : function () {};

  var _ref4 = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      _ref4$timeout = _ref4.timeout,
      timeout = _ref4$timeout === undefined ? 4500 : _ref4$timeout,
      _ref4$interval = _ref4.interval,
      interval = _ref4$interval === undefined ? 50 : _ref4$interval;

  return waitForExpect(callback, timeout, interval);
}

export { render, wait, Simulate };