import _typeof from 'babel-runtime/helpers/typeof';
import { matcherHint, printReceived, printExpected } from 'jest-matcher-utils'; //eslint-disable-line import/no-extraneous-dependencies
import { matches } from './utils';

function getDisplayName(subject) {
  if (subject && subject.constructor) {
    return subject.constructor.name;
  } else {
    return typeof subject === 'undefined' ? 'undefined' : _typeof(subject);
  }
}

var assertMessage = function assertMessage(assertionName, message, received, expected) {
  return matcherHint('' + assertionName, 'received', '') + ' \n' + message + ': ' + (printExpected(expected) + ' \nReceived: ' + printReceived(received));
};

var extensions = {
  toBeInTheDOM: function toBeInTheDOM(received) {
    getDisplayName(received);
    if (received) {
      return {
        message: function message() {
          return matcherHint('.not.toBeInTheDOM', 'received', '') + ' Expected the element not to be present' + ('\nReceived : ' + printReceived(received));
        },
        pass: true
      };
    } else {
      return {
        message: function message() {
          return matcherHint('.toBeInTheDOM', 'received', '') + ' Expected the element to be present' + ('\nReceived : ' + printReceived(received));
        },
        pass: false
      };
    }
  },
  toHaveTextContent: function toHaveTextContent(htmlElement, checkWith) {
    if (!(htmlElement instanceof HTMLElement)) throw new Error('The given subject is a ' + getDisplayName(htmlElement) + ', not an HTMLElement');

    var textContent = htmlElement.textContent;
    var pass = matches(textContent, htmlElement, checkWith);
    if (pass) {
      return {
        message: function message() {
          return assertMessage('.not.toHaveTextContent', 'Expected value not equals to', htmlElement, checkWith);
        },
        pass: true
      };
    } else {
      return {
        message: function message() {
          return assertMessage('.toHaveTextContent', 'Expected value equals to', htmlElement, checkWith);
        },
        pass: false
      };
    }
  }
};

export default extensions;